(function ($) {

  "use strict";

  Drupal.behaviors.conditional_message = {
    attach: function (context, settings) {
      // Shorthand for the configurations.
      var config = Drupal.settings.conditional_message;
      // Build AJAX URL.
      var endpoint;
      if (config.server) {
        endpoint = location.protocol + '//' + config.server + '/conditional_message_data_output';
      } else {
        endpoint = Drupal.settings.basePath + 'conditional_message_data_output';
      }
      // AJAX loads
      $.ajax({
        url: endpoint,
        crossDomain: true,
        dataType: 'json',
        success: function (response) {
          // Below are several checks to see if the message should be displayed.
          var check = [];
          // Checks if message should always be displayed.
          if (!response.always) {
            // Check sessions with localStorage.
            if (response.session) {
                var readStatus = localStorage.getItem('conditionalMessageReadStatus');
              if (readStatus == response.hash) {
                check['session'] = false;
              } else {
                check['session'] = true;
                localStorage.setItem('conditionalMessageReadStatus', response.hash);
              }
            }
            // Check close button with localStorage.
            if (response.close) {
              var closeStatus = localStorage.getItem('conditionalMessageUserClosed');
              check['close'] = closeStatus == response.hash ? false : true;
            }
            // Check roles (done in the backend).
            if (response.role == true) {
              check.role = true;
            } else if (response.role == false) {
              check.role = false;
            }
            // Check content type conditions.
            if (response.content_type) {
              check.type = false;
              for (var content_type of response.content_type) {
                var type = content_type.replace(/_/g, '-');
                var typeClass = 'node-type-' + type;
                if ($('body').hasClass(typeClass)) {
                    check.type = true;
                    break;
                }
              }
            }
            // Check paths.
            if (response.paths) {
              check.path = true;
              var treatedPaths = response.paths.map(function (p) {
                if(p !== '<front>') {
                  return Drupal.settings.basePath + p;
                } else {
                  return Drupal.settings.basePath;
                }
              });
              if (treatedPaths.indexOf(window.location.pathname) < 0) {
                check.path = false;
              }
            }
            // Check multi-site.
            if (response.selected_sites) {
              if (response.selected_sites.indexOf(config.current_site) >= 0) {
                check.multisite = true;
              } else {
                check.multisite = false;
              }
            }
            // Determine if all checks passed.
            if (Object.keys(check).length > 0) {
              var display = true;
              for (var show in check) {
                if (!check[show]) {
                  display = false;
                }
              }
            }
          }
          if (response.always || display) {
            // Check <p> tags for consistency and reset styles.
            var message;
            if (response.message.substring(0, 1) != '<') {
              message = $('<p>' + response.message + '</p>');
            } else {
              message = $(response.message);
            }
            message = $(message).addClass('conditional-message-reset');

            // Build the message HTML.
            var html = '<div class="conditional-message" style="'+
                    'background-color:#'+response.bg_color+'; '+
                    'color:#'+response.color+'; '+
                    '"><span>X</span></div>';
            var conditionalMessage = $(html).prepend(message);
            // Place the message in the page top or bottom.
            switch (response.position) {
              case  'bottom':
                $(response.target).append($(conditionalMessage).addClass('conditional-message-bottom'));
                break;

              case 'overlay':
                var conditionalMessageOverlay = conditionalMessage.wrapAll('<div class="conditional-message-overlay" />');
                $('body').append(conditionalMessageOverlay);
                break;

              default:
                $(response.target).prepend($(conditionalMessage).addClass('conditional-message-top'));
            }
            // Close button compatible through jQuery 1.5 to 1.10+.
            if ($().on) {
              $('.conditional-message span').on('click', function () {
                $(this).parent().remove();
                localStorage.setItem('conditionalMessageUserClosed', response.hash);

              });
            } else {
              $('.conditional-message span').live('click', function () {
                $(this).parent().remove();
                localStorage.setItem('conditionalMessageUserClosed', response.hash);
              });
            }
          }
        },
        error: function (xhr, textStatus, errorMessage) {
          console.log('Conditional Message AJAX: ', xhr, textStatus, errorMessage);
        }
      });
    }
  };
})(jQuery);
